'use strict';

var chunkHUR476BL_cjs = require('./chunk-HUR476BL.cjs');
var path = require('path');
var core = require('@kubb/core');
var transformers = require('@kubb/core/transformers');
var pluginOas = require('@kubb/plugin-oas');
var pluginZod = require('@kubb/plugin-zod');
var hooks = require('@kubb/plugin-oas/hooks');
var pluginTs = require('@kubb/plugin-ts');
var react = require('@kubb/react');
var jsxRuntime = require('@kubb/react/jsx-runtime');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var path__default = /*#__PURE__*/_interopDefault(path);

var clientGenerator = pluginOas.createReactGenerator({
  name: "client",
  Operation({ options, operation }) {
    const {
      plugin: {
        options: { output }
      }
    } = react.useApp();
    const { getSchemas, getName, getFile } = hooks.useOperationManager();
    const client = {
      name: getName(operation, { type: "function" }),
      file: getFile(operation)
    };
    const type = {
      file: getFile(operation, { pluginKey: [pluginTs.pluginTsName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginTs.pluginTsName], type: "type" })
    };
    const zod = {
      file: getFile(operation, { pluginKey: [pluginZod.pluginZodName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginZod.pluginZodName], type: "function" })
    };
    return /* @__PURE__ */ jsxRuntime.jsxs(react.File, { baseName: client.file.baseName, path: client.file.path, meta: client.file.meta, banner: output?.banner, footer: output?.footer, children: [
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: "client", path: options.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["RequestConfig"], path: options.importPath, isTypeOnly: true }),
      options.parser === "zod" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: [zod.schemas.response.name], root: client.file.path, path: zod.file.path }),
      /* @__PURE__ */ jsxRuntime.jsx(
        react.File.Import,
        {
          name: [
            type.schemas.request?.name,
            type.schemas.response.name,
            type.schemas.pathParams?.name,
            type.schemas.queryParams?.name,
            type.schemas.headerParams?.name,
            ...type.schemas.statusCodes?.map((item) => item.name) || []
          ].filter(Boolean),
          root: client.file.path,
          path: type.file.path,
          isTypeOnly: true
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.Client,
        {
          name: client.name,
          baseURL: options.baseURL,
          dataReturnType: options.dataReturnType,
          pathParamsType: options.pathParamsType,
          paramsType: options.paramsType,
          typeSchemas: type.schemas,
          operation,
          parser: options.parser,
          zodSchemas: zod.schemas
        }
      )
    ] });
  }
});
var operationsGenerator = pluginOas.createReactGenerator({
  name: "client",
  Operations({ operations }) {
    const {
      pluginManager,
      plugin: {
        options: { output }
      }
    } = react.useApp();
    const name = "operations";
    const file = pluginManager.getFile({ name, extname: ".ts", pluginKey: [pluginClientName] });
    return /* @__PURE__ */ jsxRuntime.jsx(react.File, { baseName: file.baseName, path: file.path, meta: file.meta, banner: output?.banner, footer: output?.footer, children: /* @__PURE__ */ jsxRuntime.jsx(chunkHUR476BL_cjs.Operations, { name, operations }) });
  }
});
var groupedClientGenerator = pluginOas.createReactGenerator({
  name: "groupedClient",
  Operations({ operations }) {
    const {
      pluginManager,
      plugin: { options }
    } = react.useApp();
    const { getName, getFile } = hooks.useOperationManager();
    const controllers = operations.reduce(
      (acc, operation) => {
        if (options.group?.type === "tag") {
          const tag = operation.getTags().at(0)?.name;
          const name = tag ? options.group?.name?.({ group: transformers.camelCase(tag) }) : void 0;
          if (!tag || !name) {
            return acc;
          }
          const file = pluginManager.getFile({
            name,
            extname: ".ts",
            pluginKey: [pluginClientName],
            options: { tag }
          });
          const client = {
            name: getName(operation, { type: "function" }),
            file: getFile(operation)
          };
          const previousFile = acc.find((item) => item.file.path === file.path);
          if (previousFile) {
            previousFile.clients.push(client);
          } else {
            acc.push({ name, file, clients: [client] });
          }
        }
        return acc;
      },
      []
    );
    return controllers.map(({ name, file, clients }) => {
      return /* @__PURE__ */ jsxRuntime.jsxs(react.File, { baseName: file.baseName, path: file.path, meta: file.meta, banner: options.output?.banner, footer: options.output?.footer, children: [
        clients.map((client) => /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: [client.name], root: file.path, path: client.file.path }, client.name)),
        /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Function, { export: true, name, children: `return { ${clients.map((client) => client.name).join(", ")} }` }) })
      ] }, file.path);
    });
  }
});

// ../plugin-client/src/plugin.ts
var pluginClientName = "plugin-client";
core.createPlugin((options) => {
  const {
    output = { path: "clients", barrelType: "named" },
    group,
    exclude = [],
    include,
    override = [],
    transformers: transformers$1 = {},
    dataReturnType = "data",
    pathParamsType = "inline",
    paramsType = "inline",
    operations = false,
    generators = [clientGenerator, group ? groupedClientGenerator : void 0, operations ? operationsGenerator : void 0].filter(Boolean),
    importPath = "@kubb/plugin-client/client",
    parser = "client"
  } = options;
  return {
    name: pluginClientName,
    options: {
      output,
      group,
      parser,
      dataReturnType,
      importPath,
      paramsType,
      pathParamsType: paramsType === "object" ? "object" : pathParamsType,
      baseURL: void 0
    },
    pre: [pluginOas.pluginOasName, parser === "zod" ? pluginZod.pluginZodName : void 0].filter(Boolean),
    resolvePath(baseName, pathMode, options2) {
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = pathMode ?? core.FileManager.getMode(path__default.default.resolve(root, output.path));
      if (options2?.tag && group?.type === "tag") {
        const groupName = group?.name ? group.name : (ctx) => `${ctx.group}Controller`;
        return path__default.default.resolve(root, output.path, groupName({ group: transformers.camelCase(options2.tag) }), baseName);
      }
      if (mode === "single") {
        return path__default.default.resolve(root, output.path);
      }
      return path__default.default.resolve(root, output.path, baseName);
    },
    resolveName(name, type) {
      const resolvedName = transformers.camelCase(name, { isFile: type === "file" });
      if (type) {
        return transformers$1?.name?.(resolvedName, type) || resolvedName;
      }
      return resolvedName;
    },
    async buildStart() {
      const [swaggerPlugin] = core.PluginManager.getDependedPlugins(this.plugins, [pluginOas.pluginOasName]);
      const oas = await swaggerPlugin.context.getOas();
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = core.FileManager.getMode(path__default.default.resolve(root, output.path));
      const baseURL = await swaggerPlugin.context.getBaseURL();
      const operationGenerator = new pluginOas.OperationGenerator(
        {
          ...this.plugin.options,
          baseURL
        },
        {
          oas,
          pluginManager: this.pluginManager,
          plugin: this.plugin,
          contentType: swaggerPlugin.context.contentType,
          exclude,
          include,
          override,
          mode
        }
      );
      const files = await operationGenerator.build(...generators);
      await this.addFile(...files);
      const barrelFiles = await this.fileManager.getBarrelFiles({
        type: output.barrelType ?? "named",
        root,
        output,
        files: this.fileManager.files,
        meta: {
          pluginKey: this.plugin.key
        },
        logger: this.logger
      });
      await this.addFile(...barrelFiles);
    }
  };
});
var queryGenerator = pluginOas.createReactGenerator({
  name: "svelte-query",
  Operation({ options, operation }) {
    const {
      plugin: {
        options: { output }
      }
    } = react.useApp();
    const { getSchemas, getName, getFile } = hooks.useOperationManager();
    const isQuery = typeof options.query === "boolean" ? true : options.query?.methods.some((method) => operation.method === method);
    !isQuery && options.mutation && options.mutation.methods.some((method) => operation.method === method);
    const query = {
      name: getName(operation, { type: "function", prefix: "create" }),
      typeName: getName(operation, { type: "type" }),
      file: getFile(operation, { prefix: "create" })
    };
    const client = {
      name: getName(operation, { type: "function", pluginKey: [pluginClientName] })
    };
    const queryOptions = {
      name: getName(operation, { type: "function", suffix: "QueryOptions" })
    };
    const queryKey = {
      name: getName(operation, { type: "const", suffix: "QueryKey" }),
      typeName: getName(operation, { type: "type", suffix: "QueryKey" })
    };
    const type = {
      file: getFile(operation, { pluginKey: [pluginTs.pluginTsName] }),
      //todo remove type?
      schemas: getSchemas(operation, { pluginKey: [pluginTs.pluginTsName], type: "type" })
    };
    const zod = {
      file: getFile(operation, { pluginKey: [pluginZod.pluginZodName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginZod.pluginZodName], type: "function" })
    };
    if (!isQuery || typeof options.query === "boolean") {
      return null;
    }
    return /* @__PURE__ */ jsxRuntime.jsxs(react.File, { baseName: query.file.baseName, path: query.file.path, meta: query.file.meta, banner: output?.banner, footer: output?.footer, children: [
      options.parser === "zod" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: [zod.schemas.response.name], root: query.file.path, path: zod.file.path }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["createQuery", "queryOptions"], path: options.query.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["QueryKey", "WithRequired", "CreateBaseQueryOptions", "CreateQueryResult"], path: options.query.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: "client", path: options.client.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["RequestConfig"], path: options.client.importPath, isTypeOnly: true }),
      options.client.dataReturnType === "full" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["ResponseConfig"], path: options.client.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsxRuntime.jsx(
        react.File.Import,
        {
          name: [
            type.schemas.request?.name,
            type.schemas.response.name,
            type.schemas.pathParams?.name,
            type.schemas.queryParams?.name,
            type.schemas.headerParams?.name,
            ...type.schemas.statusCodes?.map((item) => item.name) || []
          ].filter(Boolean),
          root: query.file.path,
          path: type.file.path,
          isTypeOnly: true
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.QueryKey,
        {
          name: queryKey.name,
          typeName: queryKey.typeName,
          operation,
          pathParamsType: options.pathParamsType,
          typeSchemas: type.schemas,
          keysFn: options.query.key
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.Client,
        {
          name: client.name,
          isExportable: false,
          isIndexable: false,
          baseURL: options.baseURL,
          operation,
          typeSchemas: type.schemas,
          zodSchemas: zod.schemas,
          dataReturnType: options.client.dataReturnType,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          parser: options.parser
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.QueryOptions,
        {
          name: queryOptions.name,
          clientName: client.name,
          queryKeyName: queryKey.name,
          typeSchemas: type.schemas,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.Query,
        {
          name: query.name,
          queryOptionsName: queryOptions.name,
          typeSchemas: type.schemas,
          pathParamsType: options.pathParamsType,
          operation,
          paramsType: options.paramsType,
          dataReturnType: options.client.dataReturnType,
          queryKeyName: queryKey.name,
          queryKeyTypeName: queryKey.typeName
        }
      )
    ] });
  }
});
var mutationGenerator = pluginOas.createReactGenerator({
  name: "svelte-query",
  Operation({ options, operation }) {
    const {
      plugin: {
        options: { output }
      }
    } = react.useApp();
    const { getSchemas, getName, getFile } = hooks.useOperationManager();
    const isQuery = typeof options.query === "boolean" ? true : options.query?.methods.some((method) => operation.method === method);
    const isMutation = !isQuery && options.mutation && options.mutation.methods.some((method) => operation.method === method);
    const mutation = {
      name: getName(operation, { type: "function", prefix: "create" }),
      typeName: getName(operation, { type: "type" }),
      file: getFile(operation, { prefix: "create" })
    };
    const type = {
      file: getFile(operation, { pluginKey: [pluginTs.pluginTsName] }),
      //todo remove type?
      schemas: getSchemas(operation, { pluginKey: [pluginTs.pluginTsName], type: "type" })
    };
    const zod = {
      file: getFile(operation, { pluginKey: [pluginZod.pluginZodName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginZod.pluginZodName], type: "function" })
    };
    const client = {
      name: getName(operation, { type: "function", pluginKey: [pluginClientName] })
    };
    const mutationKey = {
      name: getName(operation, { type: "const", suffix: "MutationKey" }),
      typeName: getName(operation, { type: "type", suffix: "MutationKey" })
    };
    if (!isMutation || typeof options.mutation === "boolean") {
      return null;
    }
    return /* @__PURE__ */ jsxRuntime.jsxs(react.File, { baseName: mutation.file.baseName, path: mutation.file.path, meta: mutation.file.meta, banner: output?.banner, footer: output?.footer, children: [
      options.parser === "zod" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: [zod.schemas.response.name], root: mutation.file.path, path: zod.file.path }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["createMutation"], path: options.mutation.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["CreateMutationOptions", "CreateMutationResult"], path: options.mutation.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: "client", path: options.client.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["RequestConfig", "ResponseConfig"], path: options.client.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsxRuntime.jsx(
        react.File.Import,
        {
          name: [
            type.schemas.request?.name,
            type.schemas.response.name,
            type.schemas.pathParams?.name,
            type.schemas.queryParams?.name,
            type.schemas.headerParams?.name,
            ...type.schemas.statusCodes?.map((item) => item.name) || []
          ].filter(Boolean),
          root: mutation.file.path,
          path: type.file.path,
          isTypeOnly: true
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.MutationKey,
        {
          name: mutationKey.name,
          typeName: mutationKey.typeName,
          operation,
          pathParamsType: options.pathParamsType,
          typeSchemas: type.schemas,
          keysFn: options.mutation.key
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.Client,
        {
          name: client.name,
          isExportable: false,
          isIndexable: false,
          baseURL: options.baseURL,
          operation,
          typeSchemas: type.schemas,
          zodSchemas: zod.schemas,
          dataReturnType: options.client.dataReturnType,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          parser: options.parser
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkHUR476BL_cjs.Mutation,
        {
          name: mutation.name,
          clientName: client.name,
          typeName: mutation.typeName,
          typeSchemas: type.schemas,
          operation,
          dataReturnType: options.client.dataReturnType,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          mutationKeyName: mutationKey.name
        }
      )
    ] });
  }
});

exports.mutationGenerator = mutationGenerator;
exports.queryGenerator = queryGenerator;
//# sourceMappingURL=chunk-VO3QBBZG.cjs.map
//# sourceMappingURL=chunk-VO3QBBZG.cjs.map